# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKRegistrationCommonPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkImageToImageMetricPython
else:
    import _itkImageToImageMetricPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageRegionPython
import itk.itkSizePython
import itk.pyBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.ITKCostFunctionsPython
import itk.vnl_cost_functionPython
import itk.vnl_unary_functionPython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkArray2DPython
import itk.itkCostFunctionPython
import itk.vnl_least_squares_functionPython
import itk.itkInterpolateImageFunctionPython
import itk.itkRGBAPixelPython
import itk.itkImageFunctionBasePython
import itk.itkFunctionBasePython
import itk.itkContinuousIndexPython
import itk.itkRGBPixelPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkSpatialObjectBasePython
import itk.itkSpatialObjectPropertyPython
import itk.itkBoundingBoxPython
import itk.itkMapContainerPython
import itk.itkVectorContainerPython
import itk.itkAffineTransformPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkVariableLengthVectorPython
class itkImageToImageMetricIF2IF2(itk.ITKCostFunctionsPython.itkSingleValuedCostFunction):
    r"""Proxy of C++ itkImageToImageMetricIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetMovingImage(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIF2D *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIF2D"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIF2D
        GetInterpolator(self) -> itkInterpolateImageFunctionIF2D
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetInterpolator(self, *args)

    def GetNumberOfMovingImageSamples(self):
        r"""GetNumberOfMovingImageSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetNumberOfMovingImageSamples(self)

    def GetNumberOfPixelsCounted(self):
        r"""GetNumberOfPixelsCounted(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetNumberOfPixelsCounted(self)

    def SetFixedImageRegion(self, reg):
        r"""
        SetFixedImageRegion(self, reg)

        Parameters
        ----------
        reg: itkImageRegion2 const

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetFixedImageRegion(self, reg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetFixedImageRegion(self)

    def SetMovingImageMask(self, *args):
        r"""
        SetMovingImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject2 *const

        SetMovingImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetMovingImageMask(self, *args)

    def GetMovingImageMask(self):
        r"""GetMovingImageMask(self) -> itkSpatialObject2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetMovingImageMask(self)

    def SetFixedImageMask(self, *args):
        r"""
        SetFixedImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject2 *const

        SetFixedImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetFixedImageMask(self, *args)

    def GetFixedImageMask(self):
        r"""GetFixedImageMask(self) -> itkSpatialObject2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetFixedImageMask(self)

    def SetFixedImageIndexes(self, indexes):
        r"""
        SetFixedImageIndexes(self, indexes)

        Parameters
        ----------
        indexes: std::vector< itkIndex2,std::allocator< itkIndex2 > > const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetFixedImageIndexes(self, indexes)

    def SetUseFixedImageIndexes(self, useIndexes):
        r"""
        SetUseFixedImageIndexes(self, useIndexes)

        Parameters
        ----------
        useIndexes: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetUseFixedImageIndexes(self, useIndexes)

    def GetUseFixedImageIndexes(self):
        r"""GetUseFixedImageIndexes(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetUseFixedImageIndexes(self)

    def SetNumberOfWorkUnits(self, numberOfThreads):
        r"""
        SetNumberOfWorkUnits(self, numberOfThreads)

        Parameters
        ----------
        numberOfThreads: unsigned int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetNumberOfWorkUnits(self, numberOfThreads)

    def GetNumberOfWorkUnits(self):
        r"""GetNumberOfWorkUnits(self) -> unsigned int const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetNumberOfWorkUnits(self)

    def SetComputeGradient(self, _arg):
        r"""
        SetComputeGradient(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetComputeGradient(self, _arg)

    def GetComputeGradient(self):
        r"""GetComputeGradient(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetComputeGradient(self)

    def ComputeGradientOn(self):
        r"""ComputeGradientOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_ComputeGradientOn(self)

    def ComputeGradientOff(self):
        r"""ComputeGradientOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_ComputeGradientOff(self)

    def ComputeGradient(self):
        r"""ComputeGradient(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_ComputeGradient(self)

    def GetModifiableGradientImage(self):
        r"""GetModifiableGradientImage(self) -> itkImageCVD22"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetModifiableGradientImage(self)

    def GetGradientImage(self, *args):
        r"""
        GetGradientImage(self) -> itkImageCVD22
        GetGradientImage(self) -> itkImageCVD22
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetGradientImage(self, *args)

    def SetTransformParameters(self, parameters):
        r"""
        SetTransformParameters(self, parameters)

        Parameters
        ----------
        parameters: itkOptimizerParametersD const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetTransformParameters(self, parameters)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_Initialize(self)

    def MultiThreadingInitialize(self):
        r"""MultiThreadingInitialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_MultiThreadingInitialize(self)

    def SetNumberOfFixedImageSamples(self, numSamples):
        r"""
        SetNumberOfFixedImageSamples(self, numSamples)

        Parameters
        ----------
        numSamples: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetNumberOfFixedImageSamples(self, numSamples)

    def GetNumberOfFixedImageSamples(self):
        r"""GetNumberOfFixedImageSamples(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetNumberOfFixedImageSamples(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetNumberOfSpatialSamples(self)

    def SetFixedImageSamplesIntensityThreshold(self, thresh):
        r"""
        SetFixedImageSamplesIntensityThreshold(self, thresh)

        Parameters
        ----------
        thresh: float const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetFixedImageSamplesIntensityThreshold(self, thresh)

    def GetFixedImageSamplesIntensityThreshold(self):
        r"""GetFixedImageSamplesIntensityThreshold(self) -> float const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetFixedImageSamplesIntensityThreshold(self)

    def SetUseFixedImageSamplesIntensityThreshold(self, useThresh):
        r"""
        SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

        Parameters
        ----------
        useThresh: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

    def GetUseFixedImageSamplesIntensityThreshold(self):
        r"""GetUseFixedImageSamplesIntensityThreshold(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetUseFixedImageSamplesIntensityThreshold(self)

    def SetUseAllPixels(self, useAllPixels):
        r"""
        SetUseAllPixels(self, useAllPixels)

        Parameters
        ----------
        useAllPixels: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetUseAllPixels(self, useAllPixels)

    def UseAllPixelsOn(self):
        r"""UseAllPixelsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_UseAllPixelsOn(self)

    def UseAllPixelsOff(self):
        r"""UseAllPixelsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_UseAllPixelsOff(self)

    def GetUseAllPixels(self):
        r"""GetUseAllPixels(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetUseAllPixels(self)

    def SetUseSequentialSampling(self, useSequential):
        r"""
        SetUseSequentialSampling(self, useSequential)

        Parameters
        ----------
        useSequential: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetUseSequentialSampling(self, useSequential)

    def GetUseSequentialSampling(self):
        r"""GetUseSequentialSampling(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetUseSequentialSampling(self)

    def ReinitializeSeed(self, *args):
        r"""
        ReinitializeSeed(self)
        ReinitializeSeed(self, seed)

        Parameters
        ----------
        seed: int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_ReinitializeSeed(self, *args)

    def SetUseCachingOfBSplineWeights(self, _arg):
        r"""
        SetUseCachingOfBSplineWeights(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_SetUseCachingOfBSplineWeights(self, _arg)

    def GetUseCachingOfBSplineWeights(self):
        r"""GetUseCachingOfBSplineWeights(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetUseCachingOfBSplineWeights(self)

    def UseCachingOfBSplineWeightsOn(self):
        r"""UseCachingOfBSplineWeightsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_UseCachingOfBSplineWeightsOn(self)

    def UseCachingOfBSplineWeightsOff(self):
        r"""UseCachingOfBSplineWeightsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_UseCachingOfBSplineWeightsOff(self)

    def GetModifiableThreader(self):
        r"""GetModifiableThreader(self) -> itkMultiThreaderBase"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetModifiableThreader(self)

    def GetThreader(self, *args):
        r"""
        GetThreader(self) -> itkMultiThreaderBase
        GetThreader(self) -> itkMultiThreaderBase
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetThreader(self, *args)

    def GetThreaderTransform(self):
        r"""GetThreaderTransform(self) -> itkTransformD22_Pointer const *"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_GetThreaderTransform(self)
    __swig_destroy__ = _itkImageToImageMetricPython.delete_itkImageToImageMetricIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageToImageMetricIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_cast(obj)

# Register itkImageToImageMetricIF2IF2 in _itkImageToImageMetricPython:
_itkImageToImageMetricPython.itkImageToImageMetricIF2IF2_swigregister(itkImageToImageMetricIF2IF2)
class itkImageToImageMetricIF3IF3(itk.ITKCostFunctionsPython.itkSingleValuedCostFunction):
    r"""Proxy of C++ itkImageToImageMetricIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetMovingImage(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIF3D *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIF3D"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIF3D
        GetInterpolator(self) -> itkInterpolateImageFunctionIF3D
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetInterpolator(self, *args)

    def GetNumberOfMovingImageSamples(self):
        r"""GetNumberOfMovingImageSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetNumberOfMovingImageSamples(self)

    def GetNumberOfPixelsCounted(self):
        r"""GetNumberOfPixelsCounted(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetNumberOfPixelsCounted(self)

    def SetFixedImageRegion(self, reg):
        r"""
        SetFixedImageRegion(self, reg)

        Parameters
        ----------
        reg: itkImageRegion3 const

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetFixedImageRegion(self, reg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetFixedImageRegion(self)

    def SetMovingImageMask(self, *args):
        r"""
        SetMovingImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject3 *const

        SetMovingImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetMovingImageMask(self, *args)

    def GetMovingImageMask(self):
        r"""GetMovingImageMask(self) -> itkSpatialObject3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetMovingImageMask(self)

    def SetFixedImageMask(self, *args):
        r"""
        SetFixedImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject3 *const

        SetFixedImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetFixedImageMask(self, *args)

    def GetFixedImageMask(self):
        r"""GetFixedImageMask(self) -> itkSpatialObject3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetFixedImageMask(self)

    def SetFixedImageIndexes(self, indexes):
        r"""
        SetFixedImageIndexes(self, indexes)

        Parameters
        ----------
        indexes: std::vector< itkIndex3,std::allocator< itkIndex3 > > const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetFixedImageIndexes(self, indexes)

    def SetUseFixedImageIndexes(self, useIndexes):
        r"""
        SetUseFixedImageIndexes(self, useIndexes)

        Parameters
        ----------
        useIndexes: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetUseFixedImageIndexes(self, useIndexes)

    def GetUseFixedImageIndexes(self):
        r"""GetUseFixedImageIndexes(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetUseFixedImageIndexes(self)

    def SetNumberOfWorkUnits(self, numberOfThreads):
        r"""
        SetNumberOfWorkUnits(self, numberOfThreads)

        Parameters
        ----------
        numberOfThreads: unsigned int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetNumberOfWorkUnits(self, numberOfThreads)

    def GetNumberOfWorkUnits(self):
        r"""GetNumberOfWorkUnits(self) -> unsigned int const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetNumberOfWorkUnits(self)

    def SetComputeGradient(self, _arg):
        r"""
        SetComputeGradient(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetComputeGradient(self, _arg)

    def GetComputeGradient(self):
        r"""GetComputeGradient(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetComputeGradient(self)

    def ComputeGradientOn(self):
        r"""ComputeGradientOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_ComputeGradientOn(self)

    def ComputeGradientOff(self):
        r"""ComputeGradientOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_ComputeGradientOff(self)

    def ComputeGradient(self):
        r"""ComputeGradient(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_ComputeGradient(self)

    def GetModifiableGradientImage(self):
        r"""GetModifiableGradientImage(self) -> itkImageCVD33"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetModifiableGradientImage(self)

    def GetGradientImage(self, *args):
        r"""
        GetGradientImage(self) -> itkImageCVD33
        GetGradientImage(self) -> itkImageCVD33
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetGradientImage(self, *args)

    def SetTransformParameters(self, parameters):
        r"""
        SetTransformParameters(self, parameters)

        Parameters
        ----------
        parameters: itkOptimizerParametersD const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetTransformParameters(self, parameters)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_Initialize(self)

    def MultiThreadingInitialize(self):
        r"""MultiThreadingInitialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_MultiThreadingInitialize(self)

    def SetNumberOfFixedImageSamples(self, numSamples):
        r"""
        SetNumberOfFixedImageSamples(self, numSamples)

        Parameters
        ----------
        numSamples: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetNumberOfFixedImageSamples(self, numSamples)

    def GetNumberOfFixedImageSamples(self):
        r"""GetNumberOfFixedImageSamples(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetNumberOfFixedImageSamples(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetNumberOfSpatialSamples(self)

    def SetFixedImageSamplesIntensityThreshold(self, thresh):
        r"""
        SetFixedImageSamplesIntensityThreshold(self, thresh)

        Parameters
        ----------
        thresh: float const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetFixedImageSamplesIntensityThreshold(self, thresh)

    def GetFixedImageSamplesIntensityThreshold(self):
        r"""GetFixedImageSamplesIntensityThreshold(self) -> float const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetFixedImageSamplesIntensityThreshold(self)

    def SetUseFixedImageSamplesIntensityThreshold(self, useThresh):
        r"""
        SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

        Parameters
        ----------
        useThresh: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

    def GetUseFixedImageSamplesIntensityThreshold(self):
        r"""GetUseFixedImageSamplesIntensityThreshold(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetUseFixedImageSamplesIntensityThreshold(self)

    def SetUseAllPixels(self, useAllPixels):
        r"""
        SetUseAllPixels(self, useAllPixels)

        Parameters
        ----------
        useAllPixels: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetUseAllPixels(self, useAllPixels)

    def UseAllPixelsOn(self):
        r"""UseAllPixelsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_UseAllPixelsOn(self)

    def UseAllPixelsOff(self):
        r"""UseAllPixelsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_UseAllPixelsOff(self)

    def GetUseAllPixels(self):
        r"""GetUseAllPixels(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetUseAllPixels(self)

    def SetUseSequentialSampling(self, useSequential):
        r"""
        SetUseSequentialSampling(self, useSequential)

        Parameters
        ----------
        useSequential: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetUseSequentialSampling(self, useSequential)

    def GetUseSequentialSampling(self):
        r"""GetUseSequentialSampling(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetUseSequentialSampling(self)

    def ReinitializeSeed(self, *args):
        r"""
        ReinitializeSeed(self)
        ReinitializeSeed(self, seed)

        Parameters
        ----------
        seed: int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_ReinitializeSeed(self, *args)

    def SetUseCachingOfBSplineWeights(self, _arg):
        r"""
        SetUseCachingOfBSplineWeights(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_SetUseCachingOfBSplineWeights(self, _arg)

    def GetUseCachingOfBSplineWeights(self):
        r"""GetUseCachingOfBSplineWeights(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetUseCachingOfBSplineWeights(self)

    def UseCachingOfBSplineWeightsOn(self):
        r"""UseCachingOfBSplineWeightsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_UseCachingOfBSplineWeightsOn(self)

    def UseCachingOfBSplineWeightsOff(self):
        r"""UseCachingOfBSplineWeightsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_UseCachingOfBSplineWeightsOff(self)

    def GetModifiableThreader(self):
        r"""GetModifiableThreader(self) -> itkMultiThreaderBase"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetModifiableThreader(self)

    def GetThreader(self, *args):
        r"""
        GetThreader(self) -> itkMultiThreaderBase
        GetThreader(self) -> itkMultiThreaderBase
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetThreader(self, *args)

    def GetThreaderTransform(self):
        r"""GetThreaderTransform(self) -> itkTransformD33_Pointer const *"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_GetThreaderTransform(self)
    __swig_destroy__ = _itkImageToImageMetricPython.delete_itkImageToImageMetricIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageToImageMetricIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_cast(obj)

# Register itkImageToImageMetricIF3IF3 in _itkImageToImageMetricPython:
_itkImageToImageMetricPython.itkImageToImageMetricIF3IF3_swigregister(itkImageToImageMetricIF3IF3)
class itkImageToImageMetricISS2ISS2(itk.ITKCostFunctionsPython.itkSingleValuedCostFunction):
    r"""Proxy of C++ itkImageToImageMetricISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetMovingImage(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionISS2D *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionISS2D"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionISS2D
        GetInterpolator(self) -> itkInterpolateImageFunctionISS2D
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetInterpolator(self, *args)

    def GetNumberOfMovingImageSamples(self):
        r"""GetNumberOfMovingImageSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetNumberOfMovingImageSamples(self)

    def GetNumberOfPixelsCounted(self):
        r"""GetNumberOfPixelsCounted(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetNumberOfPixelsCounted(self)

    def SetFixedImageRegion(self, reg):
        r"""
        SetFixedImageRegion(self, reg)

        Parameters
        ----------
        reg: itkImageRegion2 const

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetFixedImageRegion(self, reg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetFixedImageRegion(self)

    def SetMovingImageMask(self, *args):
        r"""
        SetMovingImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject2 *const

        SetMovingImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetMovingImageMask(self, *args)

    def GetMovingImageMask(self):
        r"""GetMovingImageMask(self) -> itkSpatialObject2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetMovingImageMask(self)

    def SetFixedImageMask(self, *args):
        r"""
        SetFixedImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject2 *const

        SetFixedImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetFixedImageMask(self, *args)

    def GetFixedImageMask(self):
        r"""GetFixedImageMask(self) -> itkSpatialObject2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetFixedImageMask(self)

    def SetFixedImageIndexes(self, indexes):
        r"""
        SetFixedImageIndexes(self, indexes)

        Parameters
        ----------
        indexes: std::vector< itkIndex2,std::allocator< itkIndex2 > > const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetFixedImageIndexes(self, indexes)

    def SetUseFixedImageIndexes(self, useIndexes):
        r"""
        SetUseFixedImageIndexes(self, useIndexes)

        Parameters
        ----------
        useIndexes: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetUseFixedImageIndexes(self, useIndexes)

    def GetUseFixedImageIndexes(self):
        r"""GetUseFixedImageIndexes(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetUseFixedImageIndexes(self)

    def SetNumberOfWorkUnits(self, numberOfThreads):
        r"""
        SetNumberOfWorkUnits(self, numberOfThreads)

        Parameters
        ----------
        numberOfThreads: unsigned int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetNumberOfWorkUnits(self, numberOfThreads)

    def GetNumberOfWorkUnits(self):
        r"""GetNumberOfWorkUnits(self) -> unsigned int const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetNumberOfWorkUnits(self)

    def SetComputeGradient(self, _arg):
        r"""
        SetComputeGradient(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetComputeGradient(self, _arg)

    def GetComputeGradient(self):
        r"""GetComputeGradient(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetComputeGradient(self)

    def ComputeGradientOn(self):
        r"""ComputeGradientOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_ComputeGradientOn(self)

    def ComputeGradientOff(self):
        r"""ComputeGradientOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_ComputeGradientOff(self)

    def ComputeGradient(self):
        r"""ComputeGradient(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_ComputeGradient(self)

    def GetModifiableGradientImage(self):
        r"""GetModifiableGradientImage(self) -> itkImageCVD22"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetModifiableGradientImage(self)

    def GetGradientImage(self, *args):
        r"""
        GetGradientImage(self) -> itkImageCVD22
        GetGradientImage(self) -> itkImageCVD22
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetGradientImage(self, *args)

    def SetTransformParameters(self, parameters):
        r"""
        SetTransformParameters(self, parameters)

        Parameters
        ----------
        parameters: itkOptimizerParametersD const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetTransformParameters(self, parameters)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_Initialize(self)

    def MultiThreadingInitialize(self):
        r"""MultiThreadingInitialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_MultiThreadingInitialize(self)

    def SetNumberOfFixedImageSamples(self, numSamples):
        r"""
        SetNumberOfFixedImageSamples(self, numSamples)

        Parameters
        ----------
        numSamples: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetNumberOfFixedImageSamples(self, numSamples)

    def GetNumberOfFixedImageSamples(self):
        r"""GetNumberOfFixedImageSamples(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetNumberOfFixedImageSamples(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetNumberOfSpatialSamples(self)

    def SetFixedImageSamplesIntensityThreshold(self, thresh):
        r"""
        SetFixedImageSamplesIntensityThreshold(self, thresh)

        Parameters
        ----------
        thresh: short const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetFixedImageSamplesIntensityThreshold(self, thresh)

    def GetFixedImageSamplesIntensityThreshold(self):
        r"""GetFixedImageSamplesIntensityThreshold(self) -> short const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetFixedImageSamplesIntensityThreshold(self)

    def SetUseFixedImageSamplesIntensityThreshold(self, useThresh):
        r"""
        SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

        Parameters
        ----------
        useThresh: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

    def GetUseFixedImageSamplesIntensityThreshold(self):
        r"""GetUseFixedImageSamplesIntensityThreshold(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetUseFixedImageSamplesIntensityThreshold(self)

    def SetUseAllPixels(self, useAllPixels):
        r"""
        SetUseAllPixels(self, useAllPixels)

        Parameters
        ----------
        useAllPixels: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetUseAllPixels(self, useAllPixels)

    def UseAllPixelsOn(self):
        r"""UseAllPixelsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_UseAllPixelsOn(self)

    def UseAllPixelsOff(self):
        r"""UseAllPixelsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_UseAllPixelsOff(self)

    def GetUseAllPixels(self):
        r"""GetUseAllPixels(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetUseAllPixels(self)

    def SetUseSequentialSampling(self, useSequential):
        r"""
        SetUseSequentialSampling(self, useSequential)

        Parameters
        ----------
        useSequential: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetUseSequentialSampling(self, useSequential)

    def GetUseSequentialSampling(self):
        r"""GetUseSequentialSampling(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetUseSequentialSampling(self)

    def ReinitializeSeed(self, *args):
        r"""
        ReinitializeSeed(self)
        ReinitializeSeed(self, seed)

        Parameters
        ----------
        seed: int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_ReinitializeSeed(self, *args)

    def SetUseCachingOfBSplineWeights(self, _arg):
        r"""
        SetUseCachingOfBSplineWeights(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_SetUseCachingOfBSplineWeights(self, _arg)

    def GetUseCachingOfBSplineWeights(self):
        r"""GetUseCachingOfBSplineWeights(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetUseCachingOfBSplineWeights(self)

    def UseCachingOfBSplineWeightsOn(self):
        r"""UseCachingOfBSplineWeightsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_UseCachingOfBSplineWeightsOn(self)

    def UseCachingOfBSplineWeightsOff(self):
        r"""UseCachingOfBSplineWeightsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_UseCachingOfBSplineWeightsOff(self)

    def GetModifiableThreader(self):
        r"""GetModifiableThreader(self) -> itkMultiThreaderBase"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetModifiableThreader(self)

    def GetThreader(self, *args):
        r"""
        GetThreader(self) -> itkMultiThreaderBase
        GetThreader(self) -> itkMultiThreaderBase
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetThreader(self, *args)

    def GetThreaderTransform(self):
        r"""GetThreaderTransform(self) -> itkTransformD22_Pointer const *"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_GetThreaderTransform(self)
    __swig_destroy__ = _itkImageToImageMetricPython.delete_itkImageToImageMetricISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageToImageMetricISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_cast(obj)

# Register itkImageToImageMetricISS2ISS2 in _itkImageToImageMetricPython:
_itkImageToImageMetricPython.itkImageToImageMetricISS2ISS2_swigregister(itkImageToImageMetricISS2ISS2)
class itkImageToImageMetricISS3ISS3(itk.ITKCostFunctionsPython.itkSingleValuedCostFunction):
    r"""Proxy of C++ itkImageToImageMetricISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetMovingImage(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionISS3D *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionISS3D"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionISS3D
        GetInterpolator(self) -> itkInterpolateImageFunctionISS3D
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetInterpolator(self, *args)

    def GetNumberOfMovingImageSamples(self):
        r"""GetNumberOfMovingImageSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetNumberOfMovingImageSamples(self)

    def GetNumberOfPixelsCounted(self):
        r"""GetNumberOfPixelsCounted(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetNumberOfPixelsCounted(self)

    def SetFixedImageRegion(self, reg):
        r"""
        SetFixedImageRegion(self, reg)

        Parameters
        ----------
        reg: itkImageRegion3 const

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetFixedImageRegion(self, reg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetFixedImageRegion(self)

    def SetMovingImageMask(self, *args):
        r"""
        SetMovingImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject3 *const

        SetMovingImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetMovingImageMask(self, *args)

    def GetMovingImageMask(self):
        r"""GetMovingImageMask(self) -> itkSpatialObject3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetMovingImageMask(self)

    def SetFixedImageMask(self, *args):
        r"""
        SetFixedImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject3 *const

        SetFixedImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetFixedImageMask(self, *args)

    def GetFixedImageMask(self):
        r"""GetFixedImageMask(self) -> itkSpatialObject3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetFixedImageMask(self)

    def SetFixedImageIndexes(self, indexes):
        r"""
        SetFixedImageIndexes(self, indexes)

        Parameters
        ----------
        indexes: std::vector< itkIndex3,std::allocator< itkIndex3 > > const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetFixedImageIndexes(self, indexes)

    def SetUseFixedImageIndexes(self, useIndexes):
        r"""
        SetUseFixedImageIndexes(self, useIndexes)

        Parameters
        ----------
        useIndexes: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetUseFixedImageIndexes(self, useIndexes)

    def GetUseFixedImageIndexes(self):
        r"""GetUseFixedImageIndexes(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetUseFixedImageIndexes(self)

    def SetNumberOfWorkUnits(self, numberOfThreads):
        r"""
        SetNumberOfWorkUnits(self, numberOfThreads)

        Parameters
        ----------
        numberOfThreads: unsigned int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetNumberOfWorkUnits(self, numberOfThreads)

    def GetNumberOfWorkUnits(self):
        r"""GetNumberOfWorkUnits(self) -> unsigned int const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetNumberOfWorkUnits(self)

    def SetComputeGradient(self, _arg):
        r"""
        SetComputeGradient(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetComputeGradient(self, _arg)

    def GetComputeGradient(self):
        r"""GetComputeGradient(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetComputeGradient(self)

    def ComputeGradientOn(self):
        r"""ComputeGradientOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_ComputeGradientOn(self)

    def ComputeGradientOff(self):
        r"""ComputeGradientOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_ComputeGradientOff(self)

    def ComputeGradient(self):
        r"""ComputeGradient(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_ComputeGradient(self)

    def GetModifiableGradientImage(self):
        r"""GetModifiableGradientImage(self) -> itkImageCVD33"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetModifiableGradientImage(self)

    def GetGradientImage(self, *args):
        r"""
        GetGradientImage(self) -> itkImageCVD33
        GetGradientImage(self) -> itkImageCVD33
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetGradientImage(self, *args)

    def SetTransformParameters(self, parameters):
        r"""
        SetTransformParameters(self, parameters)

        Parameters
        ----------
        parameters: itkOptimizerParametersD const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetTransformParameters(self, parameters)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_Initialize(self)

    def MultiThreadingInitialize(self):
        r"""MultiThreadingInitialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_MultiThreadingInitialize(self)

    def SetNumberOfFixedImageSamples(self, numSamples):
        r"""
        SetNumberOfFixedImageSamples(self, numSamples)

        Parameters
        ----------
        numSamples: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetNumberOfFixedImageSamples(self, numSamples)

    def GetNumberOfFixedImageSamples(self):
        r"""GetNumberOfFixedImageSamples(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetNumberOfFixedImageSamples(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetNumberOfSpatialSamples(self)

    def SetFixedImageSamplesIntensityThreshold(self, thresh):
        r"""
        SetFixedImageSamplesIntensityThreshold(self, thresh)

        Parameters
        ----------
        thresh: short const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetFixedImageSamplesIntensityThreshold(self, thresh)

    def GetFixedImageSamplesIntensityThreshold(self):
        r"""GetFixedImageSamplesIntensityThreshold(self) -> short const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetFixedImageSamplesIntensityThreshold(self)

    def SetUseFixedImageSamplesIntensityThreshold(self, useThresh):
        r"""
        SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

        Parameters
        ----------
        useThresh: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

    def GetUseFixedImageSamplesIntensityThreshold(self):
        r"""GetUseFixedImageSamplesIntensityThreshold(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetUseFixedImageSamplesIntensityThreshold(self)

    def SetUseAllPixels(self, useAllPixels):
        r"""
        SetUseAllPixels(self, useAllPixels)

        Parameters
        ----------
        useAllPixels: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetUseAllPixels(self, useAllPixels)

    def UseAllPixelsOn(self):
        r"""UseAllPixelsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_UseAllPixelsOn(self)

    def UseAllPixelsOff(self):
        r"""UseAllPixelsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_UseAllPixelsOff(self)

    def GetUseAllPixels(self):
        r"""GetUseAllPixels(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetUseAllPixels(self)

    def SetUseSequentialSampling(self, useSequential):
        r"""
        SetUseSequentialSampling(self, useSequential)

        Parameters
        ----------
        useSequential: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetUseSequentialSampling(self, useSequential)

    def GetUseSequentialSampling(self):
        r"""GetUseSequentialSampling(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetUseSequentialSampling(self)

    def ReinitializeSeed(self, *args):
        r"""
        ReinitializeSeed(self)
        ReinitializeSeed(self, seed)

        Parameters
        ----------
        seed: int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_ReinitializeSeed(self, *args)

    def SetUseCachingOfBSplineWeights(self, _arg):
        r"""
        SetUseCachingOfBSplineWeights(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_SetUseCachingOfBSplineWeights(self, _arg)

    def GetUseCachingOfBSplineWeights(self):
        r"""GetUseCachingOfBSplineWeights(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetUseCachingOfBSplineWeights(self)

    def UseCachingOfBSplineWeightsOn(self):
        r"""UseCachingOfBSplineWeightsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_UseCachingOfBSplineWeightsOn(self)

    def UseCachingOfBSplineWeightsOff(self):
        r"""UseCachingOfBSplineWeightsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_UseCachingOfBSplineWeightsOff(self)

    def GetModifiableThreader(self):
        r"""GetModifiableThreader(self) -> itkMultiThreaderBase"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetModifiableThreader(self)

    def GetThreader(self, *args):
        r"""
        GetThreader(self) -> itkMultiThreaderBase
        GetThreader(self) -> itkMultiThreaderBase
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetThreader(self, *args)

    def GetThreaderTransform(self):
        r"""GetThreaderTransform(self) -> itkTransformD33_Pointer const *"""
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_GetThreaderTransform(self)
    __swig_destroy__ = _itkImageToImageMetricPython.delete_itkImageToImageMetricISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageToImageMetricISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_cast(obj)

# Register itkImageToImageMetricISS3ISS3 in _itkImageToImageMetricPython:
_itkImageToImageMetricPython.itkImageToImageMetricISS3ISS3_swigregister(itkImageToImageMetricISS3ISS3)
class itkImageToImageMetricIUC2IUC2(itk.ITKCostFunctionsPython.itkSingleValuedCostFunction):
    r"""Proxy of C++ itkImageToImageMetricIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetMovingImage(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIUC2D *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIUC2D"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC2D
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC2D
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetInterpolator(self, *args)

    def GetNumberOfMovingImageSamples(self):
        r"""GetNumberOfMovingImageSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetNumberOfMovingImageSamples(self)

    def GetNumberOfPixelsCounted(self):
        r"""GetNumberOfPixelsCounted(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetNumberOfPixelsCounted(self)

    def SetFixedImageRegion(self, reg):
        r"""
        SetFixedImageRegion(self, reg)

        Parameters
        ----------
        reg: itkImageRegion2 const

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetFixedImageRegion(self, reg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetFixedImageRegion(self)

    def SetMovingImageMask(self, *args):
        r"""
        SetMovingImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject2 *const

        SetMovingImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetMovingImageMask(self, *args)

    def GetMovingImageMask(self):
        r"""GetMovingImageMask(self) -> itkSpatialObject2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetMovingImageMask(self)

    def SetFixedImageMask(self, *args):
        r"""
        SetFixedImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject2 *const

        SetFixedImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject2 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetFixedImageMask(self, *args)

    def GetFixedImageMask(self):
        r"""GetFixedImageMask(self) -> itkSpatialObject2"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetFixedImageMask(self)

    def SetFixedImageIndexes(self, indexes):
        r"""
        SetFixedImageIndexes(self, indexes)

        Parameters
        ----------
        indexes: std::vector< itkIndex2,std::allocator< itkIndex2 > > const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetFixedImageIndexes(self, indexes)

    def SetUseFixedImageIndexes(self, useIndexes):
        r"""
        SetUseFixedImageIndexes(self, useIndexes)

        Parameters
        ----------
        useIndexes: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetUseFixedImageIndexes(self, useIndexes)

    def GetUseFixedImageIndexes(self):
        r"""GetUseFixedImageIndexes(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetUseFixedImageIndexes(self)

    def SetNumberOfWorkUnits(self, numberOfThreads):
        r"""
        SetNumberOfWorkUnits(self, numberOfThreads)

        Parameters
        ----------
        numberOfThreads: unsigned int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetNumberOfWorkUnits(self, numberOfThreads)

    def GetNumberOfWorkUnits(self):
        r"""GetNumberOfWorkUnits(self) -> unsigned int const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetNumberOfWorkUnits(self)

    def SetComputeGradient(self, _arg):
        r"""
        SetComputeGradient(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetComputeGradient(self, _arg)

    def GetComputeGradient(self):
        r"""GetComputeGradient(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetComputeGradient(self)

    def ComputeGradientOn(self):
        r"""ComputeGradientOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_ComputeGradientOn(self)

    def ComputeGradientOff(self):
        r"""ComputeGradientOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_ComputeGradientOff(self)

    def ComputeGradient(self):
        r"""ComputeGradient(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_ComputeGradient(self)

    def GetModifiableGradientImage(self):
        r"""GetModifiableGradientImage(self) -> itkImageCVD22"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetModifiableGradientImage(self)

    def GetGradientImage(self, *args):
        r"""
        GetGradientImage(self) -> itkImageCVD22
        GetGradientImage(self) -> itkImageCVD22
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetGradientImage(self, *args)

    def SetTransformParameters(self, parameters):
        r"""
        SetTransformParameters(self, parameters)

        Parameters
        ----------
        parameters: itkOptimizerParametersD const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetTransformParameters(self, parameters)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_Initialize(self)

    def MultiThreadingInitialize(self):
        r"""MultiThreadingInitialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_MultiThreadingInitialize(self)

    def SetNumberOfFixedImageSamples(self, numSamples):
        r"""
        SetNumberOfFixedImageSamples(self, numSamples)

        Parameters
        ----------
        numSamples: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetNumberOfFixedImageSamples(self, numSamples)

    def GetNumberOfFixedImageSamples(self):
        r"""GetNumberOfFixedImageSamples(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetNumberOfFixedImageSamples(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetNumberOfSpatialSamples(self)

    def SetFixedImageSamplesIntensityThreshold(self, thresh):
        r"""
        SetFixedImageSamplesIntensityThreshold(self, thresh)

        Parameters
        ----------
        thresh: unsigned char const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetFixedImageSamplesIntensityThreshold(self, thresh)

    def GetFixedImageSamplesIntensityThreshold(self):
        r"""GetFixedImageSamplesIntensityThreshold(self) -> unsigned char const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetFixedImageSamplesIntensityThreshold(self)

    def SetUseFixedImageSamplesIntensityThreshold(self, useThresh):
        r"""
        SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

        Parameters
        ----------
        useThresh: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

    def GetUseFixedImageSamplesIntensityThreshold(self):
        r"""GetUseFixedImageSamplesIntensityThreshold(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetUseFixedImageSamplesIntensityThreshold(self)

    def SetUseAllPixels(self, useAllPixels):
        r"""
        SetUseAllPixels(self, useAllPixels)

        Parameters
        ----------
        useAllPixels: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetUseAllPixels(self, useAllPixels)

    def UseAllPixelsOn(self):
        r"""UseAllPixelsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_UseAllPixelsOn(self)

    def UseAllPixelsOff(self):
        r"""UseAllPixelsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_UseAllPixelsOff(self)

    def GetUseAllPixels(self):
        r"""GetUseAllPixels(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetUseAllPixels(self)

    def SetUseSequentialSampling(self, useSequential):
        r"""
        SetUseSequentialSampling(self, useSequential)

        Parameters
        ----------
        useSequential: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetUseSequentialSampling(self, useSequential)

    def GetUseSequentialSampling(self):
        r"""GetUseSequentialSampling(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetUseSequentialSampling(self)

    def ReinitializeSeed(self, *args):
        r"""
        ReinitializeSeed(self)
        ReinitializeSeed(self, seed)

        Parameters
        ----------
        seed: int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_ReinitializeSeed(self, *args)

    def SetUseCachingOfBSplineWeights(self, _arg):
        r"""
        SetUseCachingOfBSplineWeights(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_SetUseCachingOfBSplineWeights(self, _arg)

    def GetUseCachingOfBSplineWeights(self):
        r"""GetUseCachingOfBSplineWeights(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetUseCachingOfBSplineWeights(self)

    def UseCachingOfBSplineWeightsOn(self):
        r"""UseCachingOfBSplineWeightsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_UseCachingOfBSplineWeightsOn(self)

    def UseCachingOfBSplineWeightsOff(self):
        r"""UseCachingOfBSplineWeightsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_UseCachingOfBSplineWeightsOff(self)

    def GetModifiableThreader(self):
        r"""GetModifiableThreader(self) -> itkMultiThreaderBase"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetModifiableThreader(self)

    def GetThreader(self, *args):
        r"""
        GetThreader(self) -> itkMultiThreaderBase
        GetThreader(self) -> itkMultiThreaderBase
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetThreader(self, *args)

    def GetThreaderTransform(self):
        r"""GetThreaderTransform(self) -> itkTransformD22_Pointer const *"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_GetThreaderTransform(self)
    __swig_destroy__ = _itkImageToImageMetricPython.delete_itkImageToImageMetricIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageToImageMetricIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_cast(obj)

# Register itkImageToImageMetricIUC2IUC2 in _itkImageToImageMetricPython:
_itkImageToImageMetricPython.itkImageToImageMetricIUC2IUC2_swigregister(itkImageToImageMetricIUC2IUC2)
class itkImageToImageMetricIUC3IUC3(itk.ITKCostFunctionsPython.itkSingleValuedCostFunction):
    r"""Proxy of C++ itkImageToImageMetricIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetMovingImage(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIUC3D *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIUC3D"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC3D
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC3D
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetInterpolator(self, *args)

    def GetNumberOfMovingImageSamples(self):
        r"""GetNumberOfMovingImageSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetNumberOfMovingImageSamples(self)

    def GetNumberOfPixelsCounted(self):
        r"""GetNumberOfPixelsCounted(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetNumberOfPixelsCounted(self)

    def SetFixedImageRegion(self, reg):
        r"""
        SetFixedImageRegion(self, reg)

        Parameters
        ----------
        reg: itkImageRegion3 const

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetFixedImageRegion(self, reg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetFixedImageRegion(self)

    def SetMovingImageMask(self, *args):
        r"""
        SetMovingImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject3 *const

        SetMovingImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetMovingImageMask(self, *args)

    def GetMovingImageMask(self):
        r"""GetMovingImageMask(self) -> itkSpatialObject3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetMovingImageMask(self)

    def SetFixedImageMask(self, *args):
        r"""
        SetFixedImageMask(self, arg)

        Parameters
        ----------
        arg: itkSpatialObject3 *const

        SetFixedImageMask(self, _arg)

        Parameters
        ----------
        _arg: itkSpatialObject3 const *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetFixedImageMask(self, *args)

    def GetFixedImageMask(self):
        r"""GetFixedImageMask(self) -> itkSpatialObject3"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetFixedImageMask(self)

    def SetFixedImageIndexes(self, indexes):
        r"""
        SetFixedImageIndexes(self, indexes)

        Parameters
        ----------
        indexes: std::vector< itkIndex3,std::allocator< itkIndex3 > > const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetFixedImageIndexes(self, indexes)

    def SetUseFixedImageIndexes(self, useIndexes):
        r"""
        SetUseFixedImageIndexes(self, useIndexes)

        Parameters
        ----------
        useIndexes: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetUseFixedImageIndexes(self, useIndexes)

    def GetUseFixedImageIndexes(self):
        r"""GetUseFixedImageIndexes(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetUseFixedImageIndexes(self)

    def SetNumberOfWorkUnits(self, numberOfThreads):
        r"""
        SetNumberOfWorkUnits(self, numberOfThreads)

        Parameters
        ----------
        numberOfThreads: unsigned int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetNumberOfWorkUnits(self, numberOfThreads)

    def GetNumberOfWorkUnits(self):
        r"""GetNumberOfWorkUnits(self) -> unsigned int const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetNumberOfWorkUnits(self)

    def SetComputeGradient(self, _arg):
        r"""
        SetComputeGradient(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetComputeGradient(self, _arg)

    def GetComputeGradient(self):
        r"""GetComputeGradient(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetComputeGradient(self)

    def ComputeGradientOn(self):
        r"""ComputeGradientOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_ComputeGradientOn(self)

    def ComputeGradientOff(self):
        r"""ComputeGradientOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_ComputeGradientOff(self)

    def ComputeGradient(self):
        r"""ComputeGradient(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_ComputeGradient(self)

    def GetModifiableGradientImage(self):
        r"""GetModifiableGradientImage(self) -> itkImageCVD33"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetModifiableGradientImage(self)

    def GetGradientImage(self, *args):
        r"""
        GetGradientImage(self) -> itkImageCVD33
        GetGradientImage(self) -> itkImageCVD33
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetGradientImage(self, *args)

    def SetTransformParameters(self, parameters):
        r"""
        SetTransformParameters(self, parameters)

        Parameters
        ----------
        parameters: itkOptimizerParametersD const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetTransformParameters(self, parameters)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_Initialize(self)

    def MultiThreadingInitialize(self):
        r"""MultiThreadingInitialize(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_MultiThreadingInitialize(self)

    def SetNumberOfFixedImageSamples(self, numSamples):
        r"""
        SetNumberOfFixedImageSamples(self, numSamples)

        Parameters
        ----------
        numSamples: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetNumberOfFixedImageSamples(self, numSamples)

    def GetNumberOfFixedImageSamples(self):
        r"""GetNumberOfFixedImageSamples(self) -> unsigned long const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetNumberOfFixedImageSamples(self)

    def SetNumberOfSpatialSamples(self, num):
        r"""
        SetNumberOfSpatialSamples(self, num)

        Parameters
        ----------
        num: unsigned long

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetNumberOfSpatialSamples(self, num)

    def GetNumberOfSpatialSamples(self):
        r"""GetNumberOfSpatialSamples(self) -> unsigned long"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetNumberOfSpatialSamples(self)

    def SetFixedImageSamplesIntensityThreshold(self, thresh):
        r"""
        SetFixedImageSamplesIntensityThreshold(self, thresh)

        Parameters
        ----------
        thresh: unsigned char const &

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetFixedImageSamplesIntensityThreshold(self, thresh)

    def GetFixedImageSamplesIntensityThreshold(self):
        r"""GetFixedImageSamplesIntensityThreshold(self) -> unsigned char const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetFixedImageSamplesIntensityThreshold(self)

    def SetUseFixedImageSamplesIntensityThreshold(self, useThresh):
        r"""
        SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

        Parameters
        ----------
        useThresh: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetUseFixedImageSamplesIntensityThreshold(self, useThresh)

    def GetUseFixedImageSamplesIntensityThreshold(self):
        r"""GetUseFixedImageSamplesIntensityThreshold(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetUseFixedImageSamplesIntensityThreshold(self)

    def SetUseAllPixels(self, useAllPixels):
        r"""
        SetUseAllPixels(self, useAllPixels)

        Parameters
        ----------
        useAllPixels: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetUseAllPixels(self, useAllPixels)

    def UseAllPixelsOn(self):
        r"""UseAllPixelsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_UseAllPixelsOn(self)

    def UseAllPixelsOff(self):
        r"""UseAllPixelsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_UseAllPixelsOff(self)

    def GetUseAllPixels(self):
        r"""GetUseAllPixels(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetUseAllPixels(self)

    def SetUseSequentialSampling(self, useSequential):
        r"""
        SetUseSequentialSampling(self, useSequential)

        Parameters
        ----------
        useSequential: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetUseSequentialSampling(self, useSequential)

    def GetUseSequentialSampling(self):
        r"""GetUseSequentialSampling(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetUseSequentialSampling(self)

    def ReinitializeSeed(self, *args):
        r"""
        ReinitializeSeed(self)
        ReinitializeSeed(self, seed)

        Parameters
        ----------
        seed: int

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_ReinitializeSeed(self, *args)

    def SetUseCachingOfBSplineWeights(self, _arg):
        r"""
        SetUseCachingOfBSplineWeights(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_SetUseCachingOfBSplineWeights(self, _arg)

    def GetUseCachingOfBSplineWeights(self):
        r"""GetUseCachingOfBSplineWeights(self) -> bool const &"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetUseCachingOfBSplineWeights(self)

    def UseCachingOfBSplineWeightsOn(self):
        r"""UseCachingOfBSplineWeightsOn(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_UseCachingOfBSplineWeightsOn(self)

    def UseCachingOfBSplineWeightsOff(self):
        r"""UseCachingOfBSplineWeightsOff(self)"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_UseCachingOfBSplineWeightsOff(self)

    def GetModifiableThreader(self):
        r"""GetModifiableThreader(self) -> itkMultiThreaderBase"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetModifiableThreader(self)

    def GetThreader(self, *args):
        r"""
        GetThreader(self) -> itkMultiThreaderBase
        GetThreader(self) -> itkMultiThreaderBase
        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetThreader(self, *args)

    def GetThreaderTransform(self):
        r"""GetThreaderTransform(self) -> itkTransformD33_Pointer const *"""
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_GetThreaderTransform(self)
    __swig_destroy__ = _itkImageToImageMetricPython.delete_itkImageToImageMetricIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageToImageMetricIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_cast(obj)

# Register itkImageToImageMetricIUC3IUC3 in _itkImageToImageMetricPython:
_itkImageToImageMetricPython.itkImageToImageMetricIUC3IUC3_swigregister(itkImageToImageMetricIUC3IUC3)

